# YamlTable 

![](https://github.com/wolfgangwazzlestrauss/yamltable/workflows/build/badge.svg)

YamlTable is a Python command line utility for working with YAML files organized similar to a
relational database table. It supports YAML files organized as a list of dictionaries, which share
key names and value types. YamlTable provides commands for listing, searching, sorting, etc. data
from the supported files.


## Getting Started

### Installation

YamlTable can be installed for Python 3.7+ with `pip`.

```bash
pip install --user yamltable
```

### Commands



## Contributing

Since YamlTable is in an early development phase, it is not currently open to contributors.


## License

Licensed under the [MIT](license.txt) license.

